@@ -31,14 +31,14 @@ class User:
         response.raise_for_status()
         return response.json()['access_token']
 
-    @property
-    def data(self):
-        response = get(f"https://discord.com/api/oauth2/@me", headers={"Authorization": f"Bearer {self.auth_token}"})
+    @staticmethod
+    def data(auth_code: str):
+        response = get(f"https://discord.com/api/oauth2/@me", headers={"Authorization": f"Bearer {auth_code}"})
         response.raise_for_status()
         return response.json()['user']
 
-    @property
-    def guilds(self):
-        response = get("https://discord.com/api/v8/users/@me/guilds", headers={"Authorization": f"Bearer {self.auth_token}"})
+    @staticmethod
+    def guilds(auth_code: str):
+        response = get("https://discord.com/api/v8/users/@me/guilds", headers={"Authorization": f"Bearer {auth_code}"})
         response.raise_for_status()
         return response.json()
